==> Camelot-10.11.27.tar.gz: Camelot-10.11.27/camelot/view/proxy/__init__.py <==
#  ============================================================================
#
#  Copyright (C) 2007-2010 Conceptive Engineering bvba. All rights reserved.
#  www.conceptive.be / project-camelot@conceptive.be
#
#  This file is part of the Camelot Library.
#
#  This file may be used under the terms of the GNU General Public
#  License version 2.0 as published by the Free Software Foundation
#  and appearing in the file license.txt included in the packaging of
#  this file.  Please review this information to ensure GNU
#  General Public Licensing requirements will be met.
#
#  If you are unsure which license is appropriate for your use, please
#  visit www.python-camelot.com or contact project-camelot@conceptive.be
#
#  This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
#  WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
#
#  For use of this library in commercial applications, please contact
#  project-camelot@conceptive.be
#
#  ============================================================================

"""Proxy objects for the model that live in the GUI thread and are able to
respond immediately. They do so by keeping a local copy of the data of the real
model

We take copies of the data in the elixir model, because accessing an attribute
on the model, might cause an sql query which might take a long time, and might
freeze the gui
"""

class ValueLoading(object):
    """Class indicating that a value was not yet loaded into the
    proxy"""
    pass

==> Camelot-12.06.29.tar.gz: Camelot-12.06.29/camelot/view/proxy/__init__.py <==
#  ============================================================================
#
#  Copyright (C) 2007-2012 Conceptive Engineering bvba. All rights reserved.
#  www.conceptive.be / project-camelot@conceptive.be
#
#  This file is part of the Camelot Library.
#
#  This file may be used under the terms of the GNU General Public
#  License version 2.0 as published by the Free Software Foundation
#  and appearing in the file license.txt included in the packaging of
#  this file.  Please review this information to ensure GNU
#  General Public Licensing requirements will be met.
#
#  If you are unsure which license is appropriate for your use, please
#  visit www.python-camelot.com or contact project-camelot@conceptive.be
#
#  This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
#  WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
#
#  For use of this library in commercial applications, please contact
#  project-camelot@conceptive.be
#
#  ============================================================================

"""Proxy objects for the model that live in the GUI thread and are able to
respond immediately. They do so by keeping a local copy of the data of the real
model.

We take copies of the data in the model, because accessing an attribute
on the model, might cause an sql query which might take a long time, and might
freeze the GUI
"""

class ValueLoading(object):
    """Class indicating that a value was not yet loaded into the
    proxy"""
    pass
